@@ -8,14 +8,31 @@ use 5.14.0;
 use FindBin;
 use lib "$FindBin::Bin/../../lib";
 use Net::OAuth::LP::Client;
+use Net::OAuth::LP::Model;
 use List::AllUtils qw(first);
 
 use DDP;
 
 my $c = Net::OAuth::LP::Client->new;
-$c->staging(1);
+if (   defined($ENV{LP_CONSUMER_KEY})
+    && defined($ENV{LP_ACCESS_TOKEN})
+    && defined($ENV{LP_ACCESS_TOKEN_SECRET}))
+{
+    $c->consumer_key($ENV{LP_CONSUMER_KEY});
+    $c->access_token($ENV{LP_ACCESS_TOKEN});
+    $c->access_token_secret($ENV{LP_ACCESS_TOKEN_SECRET});
+}
 
-my $bug = $c->namespace('Bug')->by_id(859600);
+# Set whether we want staging or not
+$c->staging(0);
+
+p $c;
+
+my $model = Net::OAuth::LP::Model->new($c);
+
+p $model;
+
+my $bug = $model->namespace('Bug')->by_id($ENV{LP_BUG});
 
 say "Bug representation";
 
